<div align="center">
		<img src="./assets/logo.png" alt="logo" width="150px" height="150px"/>
		<h1>🪴 Gowest 🌱</h1>
		<p>The plant driven vehicle</p>
</div>

[![project doc](https://img.shields.io/badge/project-doc-blue?style=flat-square)]()
[![License: AGPL](https://img.shields.io/badge/License-GNU%20AGPL%20v3-yellow.svg?style=flat-square)](https://opensource.org/license/agpl-v3)
[![License: AGPL](https://img.shields.io/badge/License-CERN%20OHL%20W-yellow.svg?style=flat-square)](https://opensource.org/license/cern-ohl-w)

## Project overview

The Gowest project consist of a vehicle driven by plants used as light detector.

Gowest is split under the followings modules for flexibility, dev experience and
to improve multiple profiles contributors involvement.

- ⚙️ **[Config](./.)** (global project configuration)
- 🔌 **[Electronic](./electronic)** (schemas and constrains)
- 🎶 **[Music](./music)** (signal to music)
- 🤖 **[Robot](./robot)** (interface abstraction "voiture")
- 🪚 **[Sketch](./sketch)** (models and draws for constructing)
- 🗣️ **[Translator](./translator)** (interface Vegetal Signal)
- 🌐 **[Web](./web)** (remote control interface)

## ▶️ Usage

_TBA_

```mermaid
---
title: Gowest architecture
---
flowchart TB
	subgraph plants [Plants]
	end
	subgraph vs [Vegetal Signals]
	end
	subgraph rp [Raspberry]
		direction TB
		translator[Translator]
		ai[AI model]
		robot[Robot API]
		server[Gowest API]
		client[Gowest UI]

		translator -- Parsed datas --> ai
		ai -- Directions --> robot
		server <-- API --> robot
		server <-- API --> ai
		server <-- API --> translator
		client <-- HTTP --> server
	end
	subgraph motorization [Motorization pack]
		direction TB
		drivers[Motors drivers]
		motors[Motors]

		drivers -- Power --> motors
	end
	subgraph battery [Battery pack]
		direction TB
		battery_ctrl[Controller]
		battery_bry[Batteries]

		battery_ctrl -- Power --> battery_bry
		battery_bry -- State --> battery_ctrl
	end

	battery -- Power --> vs
	battery -- Power --> rp
	battery -- Power --> motorization

	plants -- Signals --> vs

	vs -- Serial datas --> rp
	rp -- Commands --> vs

	rp -- Commands --> motorization
```

## 💭 Philosophy

This project is split under autonomous modules as a
[monorepo](https://monorepo.tools/) to:

- Provide an unique minimalist toolchain.
- Share dependencies, interfaces, assets, ... seamlessly.
- Unify and simplify base of knowledge.
- Distribute a coherent and complete releases.

We provide and work on
[Free/Libre and Open Source Softwares](https://en.wikipedia.org/wiki/Free_and_open-source_software)
and try to use mostly well known standard (especially
[Web Standards](https://developer.mozilla.org/en-US/docs/Learn/Getting_started_with_the_web/The_web_and_web_standards))
for security, resilience, portability and compatibility reasons.

For the same reasons and for readability and as common format we prefers
[plain text](https://wiki.c2.com/?PowerOfPlainText) in most of the case.

To apply previous principles and use an ergonomic and minimalist toolchain most
of the project use:

- [json](https://developer.mozilla.org/en-US/docs/Learn/JavaScript/Objects/JSON)
  for datas and config files as it is a widely common config file syntax.
- [markdown](https://www.markdownguide.org/getting-started/) for text documents
  (documentations, wiki, ...) for his simplicity, flexibility and his widely
  usage.
- [🦕 deno](https://deno.land) as runtime and main toolchain utils for his use
  of web standard, all in one tool, single portable executable format.
- [typescript](https://www.typescriptlang.org/) for main code language for this
  support over all used platforms (embedded, server, web, ...) and the stability
  and security of a well typed interface.

## 📘 Documentation

- All public code is documented with [JsDoc](https://jsdoc.app/) and accessible
  through [doc/api](./doc/api).
- Hardware documentation and references is accessible through
  [doc/sketch](./doc/sketch) or [doc/electronic](./doc/electronic).
- Usage, setup and additional information is disponible in the
  [📖 wiki](./wiki).

## 🤝 Contributing

Any kind of contribution is welcomed. Please read
[contributing guidelines](./CONTRIBUTING.md) before and respect
[contributor covenant](https://www.contributor-covenant.org/version/2/1/code_of_conduct/).

### For local development:

**Required dependencies**:

- [`deno`](https://deno.land) To run project (code, ci, ...).
- `python3` (only necessary for [`sketch/`](./sketch) workspace).

**Before first commit or after editing [`./scripts/*`](./scripts),
[`./deno.jsonc`](./deno.jsonc)**:

- Run `deno task hooks:install`.

**Using VSCode**:

- Pre-configured workspace available in
  [`gowest.code-workspace`](./gowest.code-workspace).
- Or without local tooling install use [`.devcontainer`](./.devcontainer).
