const getStaged = new Deno.Command('git', {
	args: ['diff', '--name-only', '--staged'],
})

const { stdout } = await getStaged.output()
const staged = new TextDecoder().decode(stdout).split(/\r?\n/).filter((path) =>
	path.startsWith('sketch/') && path.endsWith('.FCStd')
)

for (const file of staged) {
	const fcinfo = new Deno.Command('python3', {
		args: ['./utils/fcinfo.py', file],
	})

	const { success, stderr, stdout } = await fcinfo.output()

	try {
		if (!success) {
			throw new Error(`python3 ./utils/fcinfo.py ${file}`, {
				cause: new TextDecoder().decode(stderr),
			})
		}

		console.log(
			`%c[scripts:fcinfo]%c ${file}`,
			'color: green; font-weight: bold',
			'',
		)

		const fcinfoFile = file.replace('.FCStd', '.fcinfo')

		Deno.writeFile(fcinfoFile, stdout)

		const stageFile = new Deno.Command('git', { args: ['add', fcinfoFile] })

		const { success: stageSuccess } = await stageFile.output()

		if (!stageSuccess) {
			throw new Error(`git add ${fcinfoFile}`, {
				cause: new TextDecoder().decode(stderr),
			})
		}
	} catch (error) {
		console.error(
			`%c[scripts:fcinfo]%c ${file}\n${error}`,
			'color: red; font-weight: bold',
			'',
		)

		Deno.exit(1)
	}
}
