import { Translator } from './translator.ts'

export class VegetalSignals {
	#readable: ReadableStream<Uint8Array>
	#writer: WritableStreamDefaultWriter<Uint8Array>

	private constructor(
		{ readable, writer }: {
			readable: ReadableStream<Uint8Array>
			writer: WritableStreamDefaultWriter<Uint8Array>
		},
	) {
		this.#readable = readable
		this.#writer = writer
	}

	static async connect(
		{ readable, writable }: ReadableWritablePair<Uint8Array, Uint8Array>,
	) {
		const readableDatas = readable
			.pipeThrough(new TextDecoderStream())
			.pipeThrough(Translator.transform)

		const writer = writable.getWriter()

		await writer.ready

		let send_serial = false

		const infos: Record<string, unknown> = {}

		for await (const event of readableDatas) {
			if (event?.kind === 'header') {
				infos[event.name] = event.value

				if (event.name === 'mode' && send_serial) {
					if (event.value) {
						break
					}
				}
				if (event.name === 'reboot') {
					send_serial = true
					await writer.write(new TextEncoder().encode('SERIAL 0\r'))
					continue
				}
			}
		}

		return new VegetalSignals({ readable, writer })
	}

	getInfos() {
		throw new Error('not implemented')
		// SN,
		// FW
	}

	async ping() {
		await this.#writer.write()
		//return Promise(resolve => this.#waitFor('OK', resolve)))
		// send OK
		// on('info', Promise.resolve)
		throw new Error('not implemented')
	}

	serial = {
		start() {
			throw new Error('not implemented')
		},
		pause() {
			throw new Error('not implemented')
		},
		stop() {
			throw new Error('not implemented')
		},
	}

	subscribe() {
		throw new Error('not implemented')
	}

	async [Symbol.asyncDispose]() {
		await this.#writer.close()
		await this.#readable.cancel()
	}
}
